
/**
 * An active object that is capable of animating any object type
 * that implements the Drawable2DInterface interface in Objectdraw.
 * 
 * @author Jim Teresco 
 */

import objectdraw.*;
import java.util.Random;

public class FallingThing extends ActiveObject {

    // settings for a simple constant speed animation
    private static final int MOVE_BY = 4;
    private static final int DELAY = 33;
    
    // our item to have fall
    private Drawable2DInterface thing;
    
    // the y-coordinate of the bottom of the canvas
    private double yMax;
    
    // constructor remembers a few things, chooses a random
    // position, places the item just off the top of the canvas
    // and starts things up
    public FallingThing(Drawable2DInterface thing, DrawingCanvas c) {
        
        // remember what we need to remember for the run method
        this.thing = thing;
        yMax = c.getHeight();
        
        // get the item into a random starting position just off the screen
        Random r = new Random();
        double width = thing.getWidth();
        double height = thing.getHeight();
        
        double xPos = r.nextDouble() * (c.getWidth() - width);
        thing.moveTo(xPos, -height);
        
        start();
    }
    
    // the life of this falling object
    public void run() {
        
        while (thing.getY() < yMax) {
            thing.move(0, MOVE_BY);
            pause(DELAY);
        }
        
        thing.removeFromCanvas();
    }
}
