
/**
 * An active object that generates, randomly, items to fall down
 * the canvas using another, generic, active object that can
 * control the fall of any object that implements the Objectdraw
 * Drawable2DInterface interface.
 * 
 * $Id: ItemGenerator.java 2566 2015-03-05 05:07:26Z terescoj $
 *
 * @author Jim Teresco
 */

import objectdraw.*;
import java.awt.*;
import java.util.Random;

public class ItemGenerator extends ActiveObject {

    // how many items will each instance generate?
    private static final int NUM_ITEMS = 100;

    // delay between items -- half second
    private static final int DELAY_FOR = 500;

    // we'll need some random numbers
    private Random r = new Random();

    // the images we'll use for some of our objects
    private Image birdImage, knightImage;

    // and we'll need to remember our canvas
    private DrawingCanvas canvas;

    // the constructor need only remember a few things 
    // and start up the thread
    public ItemGenerator(Image b, Image k, DrawingCanvas c) {

        birdImage = b;
        knightImage = k;
        canvas = c;

        start();
    }

    // the run method generates our objects periodically
    public void run() {

        // we generate 100 objects per ItemGenerator
        for (int i = 0; i < NUM_ITEMS; i++) {
            // A variable that will hold an object to be animated, and
            // since it can be one of many object types, we declare it
            // as a Drawble2DInterface.  But by doing so, we agree only
            // to interact with that object only through the methods
            // specified by that interface.
            Drawable2DInterface item;

            // we'll pick a random number that determines which of the many
            // types of objects actually is going to be created
            int itemType = r.nextInt(10);
            switch (itemType) {
                case 0:
                    item = new FilledRect(0, 0, 50, 50, canvas);
                    item.setColor(Color.red);
                    break;
                case 1:
                    item = new FilledOval(0, 0, 50, 50, canvas);
                    item.setColor(Color.blue);
                    break;
                case 2:
                    item = new FramedRect(0, 0, 50, 50, canvas);
                    item.setColor(Color.green);
                    break;
                case 3:
                    item = new FramedOval(0, 0, 50, 50, canvas);
                    item.setColor(Color.magenta);
                    break;
                case 4:
                    item = new FilledArc(0, 0, 50, 50, 45, 270, canvas);
                    item.setColor(Color.yellow);
                    break;
                case 5:
                    item = new Text("I'm falling!", 0, 0, canvas);
                    item.setColor(Color.orange);
                    break;
                case 6:
                    item = new VisibleImage(birdImage, 0, 0, canvas);
                    break;
                case 7:
                    item = new VisibleImage(knightImage, 0, 0, canvas);
                    break;
                case 8:
                    item = new TShirt(0, 0, canvas);
                    break;
                default:
                    item = new NiceBBall(0, 0, 75, canvas);
                    break;
            }
            
            new FallingThing(item, canvas);
            pause(DELAY_FOR);  // generate one every half second
        }
    }

}
